@@ -51,8 +51,10 @@ selection)."
   :group 'keyboard)
 
 (defcustom pending-delete-modeline-string " PenDel"
-  "*String to display in the modeline when Pending Delete mode is active."
-  :type 'string
+  "*String to display in the modeline when Pending Delete mode is active.
+Set this to nil if you don't want a modeline indicator."
+  :type '(choice string
+		 (const :tag "none" nil))
   :group 'keyboard)
 
 (add-minor-mode 'pending-delete-mode 'pending-delete-modeline-string)
@@ -95,24 +97,44 @@ selection)."
 	   (error-message-string e)))))
 
 
-(put 'self-insert-command 'pending-delete t)
 
-(put 'yank 'pending-delete t)
-(put 'yank-rectangle 'pending-delete t)
-(put 'yank-clipboard-selection 'pending-delete t)
-(put 'x-yank-clipboard-selection 'pending-delete t)
-(put 'toolbar-paste 'pending-delete t)
+;; now set up the keys that delete the selection and do nothing else.
+;; (Typically anything that is or could be bound to `delete' or
+;; `backspace'.)
+(mapcar #'(lambda (sym)
+	    (put sym 'pending-delete 'supersede))
+	'(delete-backward-char
+	  backward-delete-char
+	  delete-char
+	  backward-or-forward-delete-char
 
-(put 'delete-backward-char 'pending-delete 'supersede)
-(put 'backward-delete-char-untabify 'pending-delete 'supersede)
-(put 'delete-char 'pending-delete 'supersede)
-(put 'c-electric-delete 'pending-delete 'supersede)
+	  c-electric-delete
+	  cperl-electric-backspace
+	  cperl-electric-delete))
 
-;; Support the XEmacs 20.3 'delete functions
+;; now set up the keys that delete the selection and then do their normal
+;; action.
+(mapcar #'(lambda (sym)
+	    (put sym 'pending-delete t))
+	'(self-insert-command
 
-(put 'backward-or-forward-delete-char 'pending-delete 'supersede)
-(put 'cperl-electric-backspace 'pending-delete 'supersede)
-(put 'cperl-electric-delete 'pending-delete 'supersede)
+	  yank
+	  yank-rectangle
+	  yank-clipboard-selection
+	  x-yank-clipboard-selection
+	  toolbar-paste
+
+	  cperl-electric-paren
+	  cperl-electric-rparen
+	  cperl-electric-terminator
+	  cperl-electric-semi
+	  cperl-electric-lbrace
+	  cperl-electric-brace
+
+	  electric-c-sharp-sign
+	  electric-c-terminator
+	  electric-c-semi
+	  electric-c-brace))
 
 ;; Don't delete for these.  They're more problematic than helpful.
 ;;
